@@ -8,7 +8,7 @@ import f61d.LOGO as LOGO
 #from f61d.__version__ import *
 from math import ceil
 
-VERSION = (0,2,6)
+VERSION = (0,2,7)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -164,7 +164,7 @@ def prove(cont):
     
 def getLogo():
     print(colored(LOGO.randlogo(),choice(['red','yellow','green'])))
-    print(__verion__)
+    #print(__verion__)
 
 def yinyang():
     import f61d.yinyang
